@@ -1,4 +1,4 @@
-from __future__ import absolute_import, division, print_function, unicode_literals
+from __future__ import generator_stop
 
 import asyncio
 import sys
@@ -7,9 +7,6 @@ from typing import TYPE_CHECKING
 
 from .iter import _lstr, progressdata
 
-# needs python 3.4
-
-
 if TYPE_CHECKING:
 	from numbers import Number
 	from typing import IO, Iterable, Optional, Sequence, Union
