@@ -1,7 +1,4 @@
-from __future__ import absolute_import, division, print_function, unicode_literals
-
-from builtins import range, str
-from future.utils import PY2
+from __future__ import generator_stop
 
 from typing import TYPE_CHECKING
 
@@ -10,9 +7,6 @@ from .exceptions import assert_choice
 if TYPE_CHECKING:
 	from typing import Iterable, Iterator, Union
 
-if PY2:
-	bytes = bytearray
-
 def encode_binary(boolit, pad="0"):
 	# type: (Union[str, Iterator[bool]], str) -> bytes
 
