@@ -1,30 +1,20 @@
-from __future__ import absolute_import, division, print_function, unicode_literals
-
-from future.utils import PY2
+from __future__ import generator_stop
 
 import csv
 from functools import partial
-from io import open
 from itertools import islice
-from typing import TYPE_CHECKING
+from typing import Callable, Iterator, List, Optional, Sequence
 
 from .dict import itemgetter
 from .func import compose, identity, zipmap
 
-if TYPE_CHECKING:
-	from typing import Callable, Iterator, List, Optional, Sequence
 
 def iter_csv(path, delimiter=",", encoding="utf-8"):
 	# type: (str, str, str) -> Iterator[List[str]]
 
-	if PY2:
-		with open(path, "rb") as fr:
-			for data in csv.reader(fr, delimiter=delimiter.encode(encoding)):
-				yield list(field.decode(encoding) for field in data)
-	else:
-		with open(path, "rt", encoding="utf-8", newline="") as fr:
-			for data in csv.reader(fr, delimiter=delimiter):
-				yield data
+	with open(path, "rt", encoding="utf-8", newline="") as fr:
+		for data in csv.reader(fr, delimiter=delimiter):
+			yield data
 
 def read_csv(path, delimiter=",", skip=0, usecols=None, dtype=None, encoding="utf-8"):
 	# type: (str, str, int, Optional[Sequence[int]], Optional[Sequence[Callable]], str) -> Iterator[tuple]
