@@ -1,11 +1,9 @@
-from __future__ import absolute_import, division, print_function, unicode_literals
+from __future__ import generator_stop
 
 import time
-from datetime import timedelta, tzinfo
+from datetime import datetime, timedelta, timezone, tzinfo
 from typing import TYPE_CHECKING, overload
 
-from .compat.datetime import datetime, timezone
-
 if TYPE_CHECKING:
 	from datetime import time as dtime
 	from typing import Optional
