@@ -1,6 +1,4 @@
-from __future__ import absolute_import, division, print_function, unicode_literals
-
-from future.utils import viewitems
+from __future__ import generator_stop
 
 import logging
 from collections import defaultdict
@@ -10,6 +8,39 @@ from typing import TYPE_CHECKING
 if TYPE_CHECKING:
 	from typing import Any, Callable, Collection, Optional
 
+def printr(*objs, end="\n", depth=0):
+	# type: (*Any, str, int) -> None
+
+	for i, obj in enumerate(objs, 1):
+
+		if isinstance(obj, str):
+			print(obj, end="")
+		elif isinstance(obj, dict):
+			print("{", end="")
+			for j, (k, v) in enumerate(obj.items(), 1):
+				printr(k, end=end, depth=depth+1)
+				print(": ", end="")
+				printr(v, end=end, depth=depth+1)
+				if j != len(obj):
+					print(", ", end="")
+			print("}", end="")
+		else:
+			try:
+				print("(", end="")
+				for j, item in enumerate(obj, 1):
+					printr(item, end=end, depth=depth+1)
+					if j != len(obj):
+						print(", ", end="")
+				print(")", end="")
+			except TypeError:
+				print(obj, end="")
+
+		if i != len(objs):
+			print(" ", end="")
+
+	if depth == 0:
+		print(end=end)
+
 def _to_union(types):
 	# type: (Collection[str], ) -> str
 
@@ -22,6 +53,8 @@ def _to_union(types):
 	elif len(types) > 1:
 		return "Union[" + ", ".join(types) + "]"
 
+	assert False
+
 def _type_str(obj):
 	# type: (Any, ) -> str
 
@@ -71,7 +104,7 @@ def args_str(args, kwargs, maxlen=20, app="...", repr_args=True):
 	"""
 
 	args = ", ".join(_arg_str(arg, maxlen, app, repr_args) for arg in args)
-	kwargs = ", ".join(_kwarg_str(k, v, maxlen, app, repr_args) for k, v in viewitems(kwargs))
+	kwargs = ", ".join(_kwarg_str(k, v, maxlen, app, repr_args) for k, v in kwargs.items())
 
 	if args:
 		if kwargs:
