@@ -1,8 +1,7 @@
-from __future__ import absolute_import, division, print_function, unicode_literals
+from __future__ import generator_stop
 
 import asyncio
 import logging
-from io import open
 from typing import TYPE_CHECKING
 
 import aiohttp
