@@ -1,20 +1,20 @@
-from __future__ import absolute_import, division, print_function, unicode_literals
+from __future__ import generator_stop
 
 import os.path
-from io import SEEK_END, SEEK_SET, BufferedIOBase, RawIOBase, TextIOBase, TextIOWrapper, open
-from sys import stdout, version_info
+from io import SEEK_END, SEEK_SET, BufferedIOBase, RawIOBase, TextIOBase, TextIOWrapper
+from os import PathLike, fdopen, fspath
+from sys import stdout
 from typing import TYPE_CHECKING, overload
 
-from .compat.os import PathLike, fdopen, fspath
 from .iter import consume, iter_equal, resizer
 from .math import PosInfInt
 from .ops import logical_implication, logical_xor
 
 if TYPE_CHECKING:
 	from mmap import mmap
-	from typing import IO, Any, BinaryIO, Callable, Iterable, Iterator, Optional, TextIO, TypeVar, Union
+	from typing import IO, BinaryIO, Callable, Iterable, Iterator, Optional, TextIO, TypeVar, Union
 
-	PathType = Union[str, PathLike]
+	PathType = Union[str, PathLike[str]]
 	Data = TypeVar("Data", str, bytes)
 
 FILE_IO_BUFFER_SIZE = 8*1024*1024
@@ -66,13 +66,13 @@ def write_file(data, path, mode="wb", encoding=None, errors=None):
 def read_or_raise(fin, size):
 	# type: (IO[Data], int) -> Data
 
-	pass
+	...
 
 @overload
 def read_or_raise(fin, size):
 	# type: (mmap, int) -> bytes
 
-	pass
+	...
 
 def read_or_raise(fin, size):
 
@@ -135,11 +135,11 @@ def copen(file, mode="rt", archive_file=None, encoding=None, errors=None, newlin
 		ext = ext and ext.lower()
 
 	if ext == ".gz":
-		from .compat import gzip
+		import gzip
 		return gzip.open(file, mode, compresslevel=compresslevel, encoding=encoding, errors=errors, newline=newline)
 
 	elif ext == ".bz2":
-		from .compat import bz2
+		import bz2
 		return bz2.open(file, mode, compresslevel=compresslevel, encoding=encoding, errors=errors, newline=newline)
 
 	elif ext == ".zip":
@@ -151,10 +151,7 @@ def copen(file, mode="rt", archive_file=None, encoding=None, errors=None, newlin
 		newmode = _stripmode(mode)
 
 		with ZipFile(file, newmode) as zf: # note: even if the outer zip file is closed, the inner file can still be read apparently
-			if version_info >= (3, 6):
-				bf = zf.open(archive_file, newmode, force_zip64=True)
-			else:
-				bf = zf.open(archive_file, newmode)
+			bf = zf.open(archive_file, newmode, force_zip64=True)
 
 		return wrap_text(bf, mode, encoding, errors, newline)
 
@@ -174,7 +171,7 @@ class OpenFileAndDeleteOnError(object):
 	"""
 
 	def __init__(self, file, mode="rt", encoding=None, errors=None, newline=None, compresslevel=9):
-	# type: (PathType, str, Optional[str], Optional[str], Optional[str], int) -> None
+		# type: (PathType, str, Optional[str], Optional[str], Optional[str], int) -> None
 
 		encoding = _check_arguments(mode, encoding)
 
@@ -285,6 +282,8 @@ class PathOrTextIO(object):
 			self.fp = copen(fname, mode, encoding=encoding, errors=errors, newline=newline)
 
 	def __enter__(self):
+		# type: () -> IO
+
 		return self.fp
 
 	def __exit__(self, exc_type, exc_value, traceback):
@@ -442,9 +441,8 @@ class Tell(object):
 	def writable(self):
 		return self._fp.writable()
 
-from future.moves.urllib import response
-
 from collections import deque
+from urllib import response
 
 
 class BufferedTell(response.addinfourl): # fixme: untested!!!
@@ -498,7 +496,7 @@ class BufferedTell(response.addinfourl): # fixme: untested!!!
 			raise ValueError("Unknown whence")
 
 def copyfilelike(fin, fout, amount=None, buffer=FILE_IO_BUFFER_SIZE, report=None):
-	# type: (IO, IO, Optional[int], Optional[int], Optional[Callable]) -> int
+	# type: (IO, IO, Optional[int], int, Optional[Callable]) -> int
 
 	""" Read data from `fin` in chunks of size `buffer` and write them to `fout`.
 		Optionally limit the amount of data to `amount`. `report` can be a callable which receives
@@ -508,19 +506,19 @@ def copyfilelike(fin, fout, amount=None, buffer=FILE_IO_BUFFER_SIZE, report=None
 
 	# todo: have different input and output buffers
 
-	amount = amount or PosInfInt
+	_amount = amount or PosInfInt
 
 	copied = 0
-	while amount > 0:
+	while _amount > 0:
 		if report:
-			report(copied, amount+copied)
+			report(copied, _amount + copied)
 
-		data = fin.read(min(buffer, amount))
+		data = fin.read(min(buffer, _amount))
 
 		if not data:
 			break
 		fout.write(data)
-		amount -= len(data)
+		_amount -= len(data)
 		copied += len(data)
 	return copied
 
@@ -582,7 +580,7 @@ def iterfilelike(fr, start=0, amount=None, chunk_size=FILE_IO_BUFFER_SIZE):
 		return limited_file_iter(fr, amount, chunk_size)
 
 def blockfileiter(path, mode="rb", encoding=None, errors=None, start=0, amount=None, chunk_size=FILE_IO_BUFFER_SIZE):
-	# type: (PathType, str, Optional[str], Optional[str], int, Optional[int], int) -> Iterator[Data]
+	# type: (PathType, str, Optional[str], Optional[str], int, Optional[int], int) -> Iterator[Union[str, bytes]]
 
 	""" Iterate over file at `path` and yield chunks of size `chunk_size`.
 		Optionally limit output to `amount` bytes.
@@ -628,7 +626,7 @@ def blockfilesiter(paths, chunk_size=FILE_IO_BUFFER_SIZE):
 		yield chunk
 
 def bufferedfileiter(path, chunk_size, mode="rb", encoding=None, errors=None, start=0, amount=None, buffer_size=FILE_IO_BUFFER_SIZE):
-	# type: (PathType, int, str, Optional[str], Optional[str], int, Optional[int], int) -> Iterable[Data]
+	# type: (PathType, int, str, Optional[str], Optional[str], int, Optional[int], int) -> Iterable[Union[str, bytes]]
 
 	""" Iterate over file at `path` reading chunks of size `buffer_size` at a time.
 		Yields data chunks of `chunk_size` and optionally limits output to `amount` bytes.
@@ -651,21 +649,13 @@ def consume_file(filename, buffer_size=FILE_IO_BUFFER_SIZE):
 	consume(blockfileiter(filename, mode="rb", chunk_size=buffer_size))
 
 # was: same_files, textfile_equal: equal_files(*paths, mode="rt")
-def equal_files(*paths, **kwargs):
-	# type: (*PathType, **Any) -> bool
+def equal_files(*paths, mode="rb", encoding=None, errors=None, amount=None, chunk_size=FILE_IO_BUFFER_SIZE):
+	# type: (*PathType, str, Optional[str], Optional[str], Optional[int], int) -> bool
 
 	""" Check if files at `*paths` are equal. Chunks of size `chunk_size` are read at a time.
 		Data can be optionally limited to `amount`.
 	"""
 
-	# python2 fix for `equal_files(*paths, mode="rb", encoding=None, errors=None, amount=None, chunk_size=FILE_IO_BUFFER_SIZE)`
-	mode = kwargs.pop("mode", "rb")  # type: str
-	encoding = kwargs.pop("encoding", None)  # type: Optional[str]
-	errors = kwargs.pop("errors", None)  # type: Optional[str]
-	amount = kwargs.pop("amount", None)  # type: Optional[int]
-	chunk_size = kwargs.pop("chunk_size", FILE_IO_BUFFER_SIZE)  # type: int
-	assert not kwargs, "Invalid keyword arguments"
-
 	its = tuple(blockfileiter(path, mode=mode, encoding=encoding, errors=errors, amount=amount, chunk_size=chunk_size) for path in paths)
 	return iter_equal(*its)
 
