@@ -1,9 +1,8 @@
-from __future__ import absolute_import, division, print_function, unicode_literals
+from __future__ import generator_stop
 
 import logging
 import mmap
 import re
-from io import open
 from struct import unpack
 from typing import TYPE_CHECKING
 
