@@ -1,9 +1,8 @@
-from __future__ import absolute_import, division, print_function, unicode_literals
+from __future__ import generator_stop
 
 import logging
 import re
 import zlib
-from io import open
 from struct import pack, unpack
 from typing import TYPE_CHECKING
 
@@ -11,7 +10,7 @@ from ..exceptions import ParseError
 from ..file import read_or_raise
 
 if TYPE_CHECKING:
-	from typing import IO, Callable, Iterator, Tuple
+	from typing import IO, Callable, Iterator, Optional, Tuple
 
 	from _hashlib import HASH as Hashobj
 
@@ -28,9 +27,9 @@ def png_chunk(chunk_type_ascii, chunk):
 	chunk_type = chunk_type_ascii.encode("ascii")
 
 	length = pack("!I", len(chunk))
-	crc = zlib.crc32(chunk_type)
-	crc = zlib.crc32(chunk, crc)
-	crc = pack("!i", crc)
+	_crc = zlib.crc32(chunk_type)
+	_crc = zlib.crc32(chunk, _crc)
+	crc = pack("!i", _crc)
 	return length + chunk_type + chunk + crc
 
 def IHDR(width, height):
@@ -126,7 +125,7 @@ def iter_png(path, translate=True, verify_crc=True):
 
 
 def copy_png_fp(fin, fout, filter_chunks=None, verify_crc=False):
-	# type: (IO[bytes], IO[bytes], Callable[[bytes], bool], bool) -> None
+	# type: (IO[bytes], IO[bytes], Optional[Callable[[bytes], bool]], bool) -> None
 
 	""" Same as `copy_png()` except that it accepts file-like objects.
 	"""
@@ -174,7 +173,7 @@ def hash_raw_png(path, hashobj):
 def parse_tEXt(chunk):
 	# type: (bytes, ) -> Tuple[str, str]
 
-	keyword, text = chunk.split("\0")
+	keyword, text = chunk.split(b"\0")
 	return keyword.decode("latin1"), text.decode("latin1")
 
 def parse_tIME(chunk):
