@@ -1,6 +1,4 @@
-from __future__ import absolute_import, division, print_function, unicode_literals
-
-from io import open
+from __future__ import generator_stop
 
 from ..exceptions import MalformedFile
 
