@@ -1,4 +1,4 @@
-from __future__ import absolute_import, division, print_function, unicode_literals
+from __future__ import generator_stop
 
 from itertools import count
 from socket import timeout as SocketTimeout
@@ -36,4 +36,3 @@ class WrappedHTTP20Connection(object):
 			except (ConnectionResetError, SocketTimeout, StreamResetError):
 				self.connect()
 				continue
-
