@@ -1,15 +1,11 @@
-from __future__ import absolute_import, division, print_function, unicode_literals
-
-from builtins import map, range, reversed, zip
-from future.moves.itertools import zip_longest
-from future.utils import raise_from
+from __future__ import generator_stop
 
 import logging
 import random
 import sys
 from collections import deque
 from functools import partial
-from itertools import chain, combinations, count, groupby, islice, product, repeat, starmap, tee
+from itertools import chain, combinations, count, groupby, islice, product, repeat, starmap, tee, zip_longest
 from operator import add, itemgetter
 from random import randrange
 from time import sleep, time
@@ -21,24 +17,8 @@ from .ops import operator_in
 
 if TYPE_CHECKING:
 	from logging import Logger
-	from typing import (
-	    Any,
-	    Callable,
-	    Collection,
-	    Container,
-	    Dict,
-	    Iterable,
-	    Iterator,
-	    List,
-	    Optional,
-	    Sequence,
-	    Set,
-	    TextIO,
-	    Tuple,
-	    Type,
-	    TypeVar,
-	    Union,
-	)
+	from typing import (Any, Callable, Collection, Container, Dict, Iterable, Iterator, List, Optional, Sequence, Set,
+	                    TextIO, Tuple, Type, TypeVar, Union)
 
 	from .typing import Orderable, SizedIterable
 	T = TypeVar("T")
@@ -50,6 +30,22 @@ if TYPE_CHECKING:
 logger = logging.getLogger(__name__)
 logger.addHandler(logging.NullHandler())
 
+def one(it):
+	# type: (Iterator[T], ) -> T
+
+	try:
+		ret = next(it)
+	except StopIteration:
+		raise EmptyIterable()
+	try:
+		next(it)
+	except StopIteration:
+		pass
+	else:
+		raise ValueError("Iterator yielded more than one value")
+
+	return ret
+
 def iterrandrange(a, b):
 	# type: (int, int) -> Iterator[int]
 
@@ -74,7 +70,7 @@ def repeatfunc(func, times=None, *args):
 def _lstr(it, length=None):
 	if length is None:
 		try:
-			length = len(it) # type: ignore # TypeError caught below
+			length = len(it)
 		except TypeError:
 			pass
 
@@ -85,8 +81,11 @@ def _lstr(it, length=None):
 
 	return length, lstr
 
-def progressdata(it, length=None, refresh=1, end="\r", file=sys.stdout):
-	# type: (Union[Iterable, Sequence], Optional[int], float, str, Optional[TextIO]) -> Iterable
+def progressdata(it, length=None, refresh=1, end="\r", file=sys.stdout, disable=False):
+	# type: (Union[Iterable, Sequence], Optional[int], float, str, Optional[TextIO], bool) -> Iterable
+
+	if disable:
+		return it
 
 	length, lstr = _lstr(it, length)
 	last = start = time()
@@ -111,8 +110,8 @@ def progressdata(it, length=None, refresh=1, end="\r", file=sys.stdout):
 		else:
 			print("Finished {} in {} seconds.".format(total, int(duration)), end=end, file=file)
 
-def progress(it, length=None, refresh=1, end="\r", file=sys.stdout, extra_info_callback=None):
-	# type: (Union[Iterable, Collection], Optional[int], float, str, Optional[TextIO], Callable) -> Iterator
+def progress(it, length=None, refresh=1, end="\r", file=sys.stdout, extra_info_callback=None, disable=False):
+	# type: (Union[Iterable, Collection], Optional[int], float, str, Optional[TextIO], Optional[Callable], bool) -> Iterator
 
 	""" Wraps an iterable `it` to periodically print the progress every `refresh` seconds. """
 
@@ -121,26 +120,33 @@ def progress(it, length=None, refresh=1, end="\r", file=sys.stdout, extra_info_c
 		Can return 0.
 	"""
 
+	if disable:
+		return it
+
 	length, lstr = _lstr(it, length)
 	extra = ""
 	last = start = time()
 	i = 0
 
-	for i, elm in enumerate(it, 1):
-		yield elm
-		current = time()
-		if current - last > refresh:
-			last = current
-			duration = current-start
-			if extra_info_callback:
-				extra = " [{}]".format(extra_info_callback(i, length))
-			print("{}{}, running for {} seconds ({:0.2e}/s){}.".format(i, lstr, int(duration), i/duration, extra), end="\r", file=file)
-
-	duration = last-start
-	if duration > 0:
-		print("Finished {} in {} seconds ({:0.2e}/s).".format(i, int(duration), i/duration), end=end, file=file)
+	try:
+		for i, elm in enumerate(it, 1):
+			yield elm
+			current = time()
+			if current - last > refresh:
+				last = current
+				duration = current-start
+				if extra_info_callback:
+					extra = " [{}]".format(extra_info_callback(i, length))
+				print("{}{}, running for {} seconds ({:0.2e}/s){}.".format(i, lstr, int(duration), i/duration, extra), end="\r", file=file)
+	except KeyboardInterrupt:
+		print("Unsafely aborted after reading {}{} in {} seconds ({:0.2e}/s).".format(i, lstr, int(last-start), i/(last-start)), end=end, file=file)
+		raise
 	else:
-		print("Finished {} in {} seconds.".format(i, int(duration)), end=end, file=file)
+		duration = last-start
+		if duration > 0:
+			print("Finished {} in {} seconds ({:0.2e}/s).".format(i, int(duration), i/duration), end=end, file=file)
+		else:
+			print("Finished {} in {} seconds.".format(i, int(duration)), end=end, file=file)
 
 class Progress(object):
 
@@ -259,7 +265,7 @@ def empty():
 	"""
 
 	return
-	yield # pylint: disable=unreachable
+	yield # type: ignore # pylint: disable=unreachable
 
 def lastdefault(it, default=None):
 	# type: (Iterable[T], Optional[T]) -> Optional[T]
@@ -283,8 +289,7 @@ def last(it):
 	try:
 		return deque(it, 1).pop()
 	except IndexError:
-		raise_from(EmptyIterable("Empty iterable"), None)
-		raise  # just to appease mypy
+		raise EmptyIterable("Empty iterable") from None
 
 def batch(it, n, func=None):
 	# type: (Iterable[Any], int, Optional[Callable]) -> Iterator[Any] # return type cannot be more specific because of filter()
