@@ -1,6 +1,4 @@
-from __future__ import absolute_import, division, print_function, unicode_literals
-
-from future.utils import viewkeys
+from __future__ import generator_stop
 
 import csv
 import json
@@ -13,7 +11,6 @@ from typing import IO, TYPE_CHECKING, Any, Callable, Dict, FrozenSet, Iterator,
 from typing_extensions import TypedDict
 
 from .atomic import TransactionalCreateFile, sopen
-from .compat import FileNotFoundError
 from .datetime import now
 from .file import copen
 from .filesystem import mdatetime
@@ -83,7 +80,7 @@ def read_json(path, schema=None, cls=None, object_hook=None):
 	return obj
 
 def write_json(obj, path, schema=None, ensure_ascii=False, cls=None, indent=None, sort_keys=False, default=None, safe=False):
-	# type: (Any, PathStr, Optional[Union[str, JsonDict]], bool, Optional[Type[json.JSONEncoder]], Optional[str], bool, Optional[Callable], bool) -> None
+	# type: (Any, PathStr, Optional[Union[str, JsonDict]], bool, Optional[Type[json.JSONEncoder]], Optional[Union[str, int]], bool, Optional[Callable], bool) -> None
 
 	""" Writes python object `obj` to `path` as json files and optionally validates the object
 		according to `schema`. The validation requires `jsonschema`.
@@ -240,7 +237,7 @@ def key_to_hash(key, default=None):
 	return md5(binary).hexdigest()  # nosec
 
 def cache(path, duration=None, ensure_ascii=False, indent=None, sort_keys=False, default=None, object_hook=None):
-	# type: (Path, Optional[timedelta], bool, Optional[str], bool, Optional[Callable], Optional[Callable]) -> Callable
+	# type: (Path, Optional[timedelta], bool, Optional[Union[str, int]], bool, Optional[Callable], Optional[Callable]) -> Callable
 
 	""" Decorator to cache results of function to json files at `path` for `duration`.
 		The remaining parameters are passed through to `json.dump`.
@@ -335,7 +332,7 @@ class JsonLinesFormatter(logging.Formatter):
 		# type: (FrozenSet[str], FrozenSet[str], Optional[Callable]) -> None
 
 		logging.Formatter.__init__(self)
-		self.include_b = include & viewkeys(self.myfields)
+		self.include_b = include & self.myfields.keys()
 		self.builtins = builtins
 		self.dumps = partial(json.dumps, ensure_ascii=False, indent=None, sort_keys=True, default=default)
 
