@@ -1,14 +1,15 @@
-from __future__ import absolute_import, division, print_function, unicode_literals
+from __future__ import generator_stop
 
-from io import open
+from typing import TYPE_CHECKING
 
 from nltk.tokenize import word_tokenize
 
-from .compat.os import PathLike
+if TYPE_CHECKING:
+	from os import PathLike
 
 
 def count_words_in_file(path, encoding="utf-8"):
-	# type: (PathLike, ) -> int
+	# type: (PathLike, str) -> int
 
 	with open(path, "r", encoding=encoding) as fr:
 		return sum(len(word_tokenize(line)) for line in fr)
