@@ -1,4 +1,4 @@
-from __future__ import absolute_import, division, print_function, unicode_literals
+from __future__ import generator_stop
 
 import logging
 import os
@@ -6,20 +6,15 @@ import signal
 from ctypes import WinError, byref, c_wchar_p, cast, create_unicode_buffer, memset, sizeof
 from ctypes.wintypes import DWORD, LPCWSTR, ULARGE_INTEGER
 from msvcrt import get_osfhandle
+from os import fspath
 from typing import TYPE_CHECKING
 
 from cwinsdk.shared.ehstorioctl import MAX_PATH
 from cwinsdk.shared.ntdef import PWSTR
 from cwinsdk.um.combaseapi import CoTaskMemFree
 from cwinsdk.um.consoleapi import ENABLE_VIRTUAL_TERMINAL_PROCESSING, GetConsoleMode, SetConsoleMode
-from cwinsdk.um.fileapi import (
-    INVALID_FILE_ATTRIBUTES,
-    GetDiskFreeSpaceExW,
-    GetFileAttributesW,
-    GetVolumeInformationW,
-    LockFileEx,
-    UnlockFileEx,
-)
+from cwinsdk.um.fileapi import (INVALID_FILE_ATTRIBUTES, GetDiskFreeSpaceExW, GetFileAttributesW, GetVolumeInformationW,
+                                LockFileEx, UnlockFileEx)
 from cwinsdk.um.KnownFolders import FOLDERID_RoamingAppData
 from cwinsdk.um.minwinbase import LOCKFILE_EXCLUSIVE_LOCK, LOCKFILE_FAIL_IMMEDIATELY, OVERLAPPED
 from cwinsdk.um.processenv import GetStdHandle
@@ -27,15 +22,13 @@ from cwinsdk.um.ShlObj_core import SHGetKnownFolderPath
 from cwinsdk.um.WinBase import STD_OUTPUT_HANDLE
 from cwinsdk.um.winnt import FILE_ATTRIBUTE_REPARSE_POINT
 
-from .compat.os import fspath
 from .os_shared import _usagetuple, _volumeinfotuple
 
 if TYPE_CHECKING:
 	from ctypes.wintypes import HANDLE
+	from os import PathLike
 	from typing import IO, Union
 
-	from .compat.os import PathLike
-
 	PathType = Union[str, PathLike]
 
 unc_prefix = "\\\\?\\"
