@@ -1,16 +1,15 @@
-from __future__ import absolute_import, division, print_function, unicode_literals
+from __future__ import generator_stop
 
 import logging
 import pickle  # nosec
 from datetime import timedelta
 from functools import wraps
+from os import fspath
 from pickle import HIGHEST_PROTOCOL  # nosec
 from typing import TYPE_CHECKING
 
 from .atomic import sopen
-from .compat import FileNotFoundError
 from .compat.contextlib import nullcontext
-from .compat.os import fspath
 from .datetime import now
 from .file import copen
 from .filesystem import mdatetime
@@ -18,10 +17,9 @@ from .object import args_to_key
 from .time import PrintStatementTime
 
 if TYPE_CHECKING:
+	from pathlib import Path
 	from typing import Any, Callable, Iterable, Iterator, Optional
 
-	from .compat.pathlib import Path
-
 logger = logging.getLogger(__name__)
 
 def read_pickle(path):
@@ -97,7 +95,7 @@ def cache(path, duration=None, generator=False, protocol=HIGHEST_PROTOCOL, ignor
 			where `ppv` is assigned the  pickle protocol version.
 	"""
 
-	duration = duration or timedelta.max
+	_duration = duration or timedelta.max
 
 	if not verbose:
 		context = nullcontext
@@ -120,7 +118,7 @@ def cache(path, duration=None, generator=False, protocol=HIGHEST_PROTOCOL, ignor
 				fullpath = fspath(path).format(ppv=protocol)
 
 			try:
-				invalid = now() - mdatetime(fullpath) > duration
+				invalid = now() - mdatetime(fullpath) > _duration
 			except FileNotFoundError:
 				invalid = True
 
