@@ -1,4 +1,4 @@
-from __future__ import absolute_import, division, print_function, unicode_literals
+from __future__ import generator_stop
 
 """ Scripts using line_profiler.profile can import this to be able to run unmodified
 	without the profiler present.
