@@ -1,6 +1,4 @@
-from __future__ import absolute_import, division, print_function, unicode_literals
-
-from builtins import range
+from __future__ import generator_stop
 
 from random import choice, randrange
 from typing import TYPE_CHECKING
@@ -23,7 +21,7 @@ def randbytes(size):
 	""" Returns (noncryptographic) random bytes of length `length`.
 	"""
 
-	return b"".join(chr(randrange(0, 256)) for _ in range(size))  # nosec
+	return bytes(randrange(0, 256) for _ in range(size))  # nosec
 
 def rgb_colors():
 	# type: () -> Iterator[Tuple[int, int, int]]
