@@ -1,6 +1,4 @@
-from __future__ import absolute_import, division, print_function, unicode_literals
-
-from builtins import range
+from __future__ import generator_stop
 
 from operator import itemgetter
 from typing import TYPE_CHECKING
@@ -11,7 +9,7 @@ from .indexing import triangular_indices
 if TYPE_CHECKING:
 	from typing import Callable, Dict, Iterator, MutableSequence, Optional, Sequence, Tuple, TypeVar
 
-	from .typing import Comparable
+	from .typing import Comparable, Orderable
 	T = TypeVar("T")
 
 class LazyStringList(object):
@@ -83,8 +81,8 @@ def batch(seq, size):
 	# type: (Sequence[T], int) -> Iterator[Sequence[T]]
 
 	""" Similar to `iter.batch()` except that it returns slices of a sequence.
-		sliding_window([1, 2, 3], 2) -> [1, 2], [2, 3]
-		sliding_window([1, 2, 3, 4, 5], 2, 3) -> [1, 2], [4, 5]
+		batch([1, 2, 3], 2) -> [1, 2], [3]
+		batch([1, 2, 3, 4, 5], 3) -> [1, 2, 3], [4, 5]
 	"""
 
 	if size < 1:
@@ -116,7 +114,7 @@ def remove_duplicate_rows_from_sorted_table(seq, key):
 	return delete_duplicates_from_sorted_sequence(seq, itemgetter(key))
 
 def cycle_sort(seq):
-	# type: (MutableSequence[T], ) -> Iterator[Tuple[int, int]]
+	# type: (MutableSequence[Orderable], ) -> Iterator[Tuple[int, int]]
 
 	""" Sort a sequence in place and yield swaps.
 		based on: https://rosettacode.org/wiki/Sorting_algorithms/Cycle_sort#Python
