@@ -1,6 +1,4 @@
-from __future__ import absolute_import, division, print_function, unicode_literals
-
-from builtins import map, range
+from __future__ import generator_stop
 
 from math import pow
 from random import sample
