@@ -1,4 +1,4 @@
-from __future__ import absolute_import, division, print_function, unicode_literals
+from __future__ import generator_stop
 
 from collections.abc import Iterable, Sized
 from typing import TYPE_CHECKING
@@ -45,8 +45,8 @@ if TYPE_CHECKING:
 
 	class Computable(Protocol):
 
-		def __neg__(self, other):
-			# type: (Any, ) -> Any
+		def __neg__(self):
+			# type: () -> Any
 			...
 
 		def __add__(self, other):
@@ -69,14 +69,14 @@ if TYPE_CHECKING:
 			# type: (Any, ) -> Any
 			...
 
-		def __abs__(self, other):
-			# type: (Any, ) -> Any
+		def __abs__(self):
+			# type: () -> Any
 			...
 
 	class MutableComputable(Protocol):
 
-		def __neg__(self, other):
-			# type: (Any, ) -> Any
+		def __neg__(self):
+			# type: () -> Any
 			...
 
 		def __add__(self, other):
